|travis| |appveyor|

cpuid-py
=======

cpuid Pythonic API

Getting started 
---------------

Stable version:

.. code-block:: bash

    $ pip install --upgrade cpuid-py

Development version:

.. code-block:: bash

    $ pip install --upgrade --index-url https://test.pypi.org/pypi/ cpuid-py

.. |travis| image:: https://travis-ci.org/fpelliccioni/cpuid-py.svg?branch=master
 		   :target: https://travis-ci.org/fpelliccioni/cpuid-py
 		   
.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/fpelliccioni/cpuid-py?branch=master&svg=true
  		     :target: https://ci.appveyor.com/project/fpelliccioni/cpuid-py?branch=master


